note 44614 added to function.include
| From: | mattcimino at gardiners dot com | Date: | Wed, 11 Aug 2004 00:47:39 +0000 |
| Subject: | note 44614 added to function.include | ||
| Groups: | php.notes | ||
| Request: | Send a blank email to php-notes+get-79734@lists.php.net to get a copy of this message | ||
To avoid painfully SLOW INCLUDES under IIS be sure to set "output_buffering = on" in
php.ini. File includes dropped from about 2 seconds to 0 seconds when this was set.
----
Manual Page -- http://www.php.net/manual/en/function.include.php
Edit -- http://master.php.net/manage/user-notes.php?action=edit+44614
Delete -- http://master.php.net/manage/user-notes.php?action=delete+44614&report=yes
Reject -- http://master.php.net/manage/user-notes.php?action=reject+44614&report=yes
Search -- http://master.php.net/manage/user-notes.php